<?php
/**
 * 未登録ユーザの予約キャンセル
 *
 * 予約コード,Eメールを入力して予約をキャンセルする。
 *
 * @package     ci-hotel
 * @author      Teruki Hosokawa <hosotk@gmail.com>
 * @licence     New BSD Licence
 *
 */
require_once (dirname(__FILE__) . "/FRONT_Controller.php");

class Cancel extends FRONT_Controller {
    
    function Cancel()
    {
        parent::FRONT_Controller();
        $this->load->model('Common_model');
        $this->load->model('Res_model');
        $this->load->model('Hotel_model');
    }
    
    function index($hotelid)
    {
        $this->load->helper(array('form', 'url'));
        $this->load->library('form_validation');
        $this->form_validation->set_error_delimiters('<div class="error">', '</div>');
        
        $this->form_validation->set_rules('rescode', '予約コード', 'required|trim|xss_clean');
        $this->form_validation->set_rules('email', 'メールアドレス', 'required|valid_email|trim|xss_clean');
        
        if ($this->form_validation->run() == FALSE)
        {
            $this->load->view('cancel/index');
            return;
        }
        else
        {
            $rescode = set_value('rescode');
            $email = set_value('email');
            
            $this->db->where('rescode', $rescode);
            $query = $this->db->get('reservation', 1);
            if ($query->num_rows() <= 0)
            {
                
                
                $this->load->view('cancel/index');
                return;
            }
            $reservation = $query->row_array();
            $resid = $reservation['resid'];
            
            $this->db->where('resid', $resid);
            $this->db->where('email', $email);
            $query = $this->db->get('resmember', 1);
            if ($query->num_rows() <= 0)
            {
                $data['error'] = array();
                $data['error'][] = '予約コードまたはEメールアドレスが間違っています。';
                $this->load->vars($data);
                $this->load->view('cancel/index');
                return;
            }
            $row = $query->row_array();
            
            // OK
            
            // 予約id,Eメールアドレスをsessionに保存する。
            $this->phpsession->save('cancel', 
                array('rescode' => $rescode, 'resid' => $resid, 'email' => $email));
            
            redirect('cancel/confirm/' . $hotelid);
        }
        $this->load->view('cancel/index');
    }
    
    /**
     * キャンセル内容確認
     */
    function confirm($hotelid)
    {
        $this->load->helper(array('form', 'url'));
        
        $cancel = $this->phpsession->get('cancel');
        if (!isset($cancel))
        {
            var_dump($cancel);
            die('cancel code is not set.');
        }
        
        if ($this->input->post('submit'))
        {
            $this->Res_model->cancel($cancel['resid'], 1, $this->Hotel_model);
            $this->phpsession->clear('cancel');
            redirect('cancel/accept/' . $hotelid);
        }
        
        $resid = $cancel['resid'];
        
        $this->db->where('resid', $resid);
        $this->db->where('status >', 0);
        $query = $this->db->get('reservation', 1);
        if ($query->num_rows() <= 0)
        {
            return '';
        }
        $reservation = $query->row_array();
        
        $this->db->where('resid', $resid);
        $query = $this->db->get('resmember', 1);
        if ($query->num_rows() <= 0)
        {
            return '';
        }
        $resmember = $query->row_array();
        
        $planid = $reservation['planid'];
        $roomtypeid = $reservation['roomtypeid'];
        $this->db->where('planid', $planid);
        $query = $this->db->get('plans', 1);
        if ($query->num_rows() <= 0)
        {
            return '';
        }
        $plan = $query->row_array();
        
        $this->db->where('roomtypeid', $roomtypeid);
        $query = $this->db->get('roomtypes', 1);
        if ($query->num_rows() <= 0)
        {
            return '';
        }
        $roomtype = $query->row_array();
        
        $this->db->where('resid', $resid);
        $this->db->order_by('day DESC');
        $query = $this->db->get('resrooms');
        if ($query->num_rows() <= 0)
        {
            return '';
        }
        $resrooms = $query->result_array();
        
        $this->db->where('resid', $resid);
        $this->db->order_by('day DESC');
        $query = $this->db->get('resoptions');
        if ($query->num_rows() <= 0)
        {
            return '';
        }
        $resoptions = $query->result_array();
        
        ob_start();
        
        echo '<table class="inp">' . "\n";
        
        echo "<tr><th>予約コード : </th><td>" . $reservation['rescode'] . "</td></tr>\n";
        echo "<tr><th>予約受付日 : </th><td>" . $reservation['created'] . "</td></tr>\n";
        echo "<tr><th>チェックイン日 : </th><td>" . $reservation['cin'] . ' (' . $this->Common_model->week($reservation['cin']) . ')' . "</td></tr>\n";
        echo "<tr><th>チェックアウト日 : </th><td>" . $reservation['cout'] . ' (' . $this->Common_model->week($reservation['cout']) . ')' . "</td></tr>\n";
        echo "<tr><th>宿泊日数 : </th><td>" . $reservation['stay_days'] . ' 日' . "</td></tr>\n";
        echo "<tr><th>プラン名 : </th><td>" . $plan['plan_name'] . "</td></tr>\n";
        echo "<tr><th>部屋タイプ : </th><td>" . $roomtype['roomtype_name'] . "</td></tr>\n";
        echo "<tr><th>部屋数 : </th><td>" . $reservation['room_num'] . " 部屋" . "</td></tr>\n";
        echo "<tr><th>人数 : </th><td>" . "\n";
        
        $tmp = '';
        for ($i = 0; $i < $reservation['room_num']; $i++)
        {
            $resroom = $resrooms[$i];
            echo $resroom['room_no'] . '部屋目' . "<br />\n";
            if ($resroom['basic_num'] > 0)
            {
                echo "・大人 : "  . $resroom['basic_num']  . " 人 ";
            }
            if ($resroom['child1_num'] > 0)
            {
                echo "・子供A : " . $resroom['child1_num'] . " 人 ";
            }
            if ($resroom['child2_num'] > 0)
            {
                echo "・子供B : " . $resroom['child2_num'] . " 人 ";
            }
            if ($resroom['child3_num'] > 0)
            {
                echo "・子供C : " . $resroom['child3_num'] . " 人 ";
            }
            if ($resroom['child4_num'] > 0)
            {
                echo "・子供D : " . $resroom['child4_num'] . " 人 ";
            }
            echo "<br />\n";
        }
        echo "</td></tr>\n";
        
        echo "<tr><th>料金 : </th><td>" . "\n";
        
        $tmp = '';
        $strDay = '';
        foreach ($resrooms as $resroom)
        {
            if ($strDay != $resroom['day'])
            {
                echo $resroom['day'] . "<br />\n";
                $strDay = $resroom['day'];
            }
            echo $resroom['room_no'] . '部屋目' . "<br />\n";
            if ($resroom['basic_num'] > 0)
            {
                echo "・大人 : ";
                $temp = $resroom['basic_num'] * $resroom['basic_price'];
                echo $resroom['basic_num'] . ' 人 x ' . number_format($resroom['basic_price']) . ' 円 = ' . number_format($temp) . ' 円' . "<br />\n";
            }
            if ($resroom['child1_num'] > 0)
            {
                echo "・子供A : ";
                $temp = $resroom['child1_num'] * $resrooom['child1_price'];
                echo $resroom['child1_num'] . ' 人 x ' . number_format($resroom['child1_price']) . ' 円 = ' . number_format($temp) . ' 円' . "<br />\n";
            }
            if ($resroom['child2_num'] > 0)
            {
                echo "・子供B : ";
                $temp = $resroom['child2_num'] * $resroom['child2_price'];
                echo $resroom['child2_num'] . ' 人 x ' . number_format($resroom['child2_price']) . ' 円 = ' . number_format($temp) . ' 円' . "<br />\n";
            }
            if ($resroom['child3_num'] > 0)
            {
                echo "・子供C : ";
                $temp = $resroom['child3_num'] * $resroom['child3_price'];
                echo $resroom['child3_num'] . ' 人 x ' . number_format($room_i['child3_price']) . ' 円 = ' . number_format($temp) . ' 円' . "<br />\n";
            }
            if ($resroom['child4_num'] > 0)
            {
                echo "・子供D : ";
                $temp = $resroom['child4_num'] * $resroom['child4_price'];
                echo $resroom['child4_num'] . ' 人 x ' . number_format($room_i['child4_price']) . ' 円 = ' . number_format($temp) . ' 円' . "<br />\n";
            }
        }
        echo "</td></tr>\n";
        
        echo "<tr><th>オプション : </th><td>" . "\n";
        
        $tmp = '';
        $strDay = '';
        
        $tmp = '';
        $strDay = '';
        foreach ($resoptions as $resoption)
        {
            if ($strDay != $resoption['day'])
            {
                echo $resoption['day'] . "<br />\n";
                $strDay = $resoption['day'];
            }
            echo '・' . $resoption['option_name'] . ':';
            echo number_format($resoption['price']) . '円' . " x ";
            echo $resoption['num'] . " " . $resoption['unitname'] . " = ";
            $option_subtotal = $resoption['price'] * $resoption['num'];
            echo number_format($option_subtotal) . '円' . "<br />\n";
        }
        echo "</td></tr>\n";
        
        echo "<tr><th>合計 : </th><td>" . number_format($reservation['total_price']) . "円" . "</td></tr>\n";
        echo "<tr><th>申込者氏名: </th><td>" . $resmember['name'] . "</td></tr>\n";
        echo "</table>\n";
        
        $data['contents'] = ob_get_contents();
        ob_end_clean();
        $this->load->vars($data);
        
        $this->load->view('cancel/confirm');
    }
    
    /**
     * キャンセル完了
     */
    function accept($hotelid)
    {
        $this->load->view('cancel/accept');
    }
}

